@@ -92,6 +92,9 @@ def parse_input(input):
 
 	elif 'hungry' in input or set(sent.food).intersection(set(input.split())):
 		return food(input)
+
+	elif 'gas' in input:
+		return gas(input)
 		
 	elif exists_in_order(['my','location'],input.split()) or exists_in_order(['where', 'i'],input.split()):
 		return where_am_i(input)
@@ -305,8 +308,14 @@ def food(input):
 	#TODO - cmdline
 	return 'Let me search for '+food, "gobject.timeout_add(500, os.system, 'python /opt/modrana/modrana.py --local-search "+food+"')"
 
+def gas(input):
+	return 'Let me search for gas stations.', "gobject.timeout_add(500, os.system, 'python /opt/modrana/modrana.py --local-search gas')"
+
 def get_weather(input):
-	f = urllib2.urlopen('http://api.wunderground.com/api/0a02b434d9bf118f/geolookup/conditions/q/NY/New_York.json')
+	try:
+		f = urllib2.urlopen('http://api.wunderground.com/api/0a02b434d9bf118f/geolookup/conditions/q/NY/New_York.json')
+	except urllib2.URLError:
+		return "I need an internet connection to look up the weather, sorry."
 	json_string = f.read()
 	parsed_json = json.loads(json_string)
 	location = parsed_json['location']['city']
@@ -326,7 +335,7 @@ def get_weather(input):
 																	.replace("NW", "northwest")\
 																	.replace("MPH", "miles per hour")
 	precip = float(parsed_json['current_observation']['precip_1hr_in'])
-	weather = parsed_json['current_observation']['weather']
+	weather = parsed_json['current_observation']['weather'].lower()
 	f.close()
 	if overlap(['rain', 'rainy', 'raining'], input):
 		if precip>0.2 or 'rain' in weather.lower() or ('storm' in weather.lower() and not 'snow' in weather.lower()):
@@ -354,6 +363,9 @@ def get_weather(input):
 			return "I don't think you need an umbrella; the weather in %s is %s." % (location, weather), None
 	elif "wind" in input:
 		return "The wind in %s is %s." % (location, wind_string.lower()), None
+	else:
+		if "tornado" in weather:
+			return "Tornado. Get down to the cellar.", None
 	return "The weather in %s is %s degrees and %s." % (location, temp_f, weather), None
 
 def settings(input):
@@ -530,7 +542,6 @@ def new_alarm(input):
 	time = time.replace(hour=hour,minute=minute,second=0,microsecond=0)
 
 	event.alarm_time = float(time.strftime("%s"))
-	event.flags = alarm.ALARM_EVENT_BOOT
 
 	action_stop, action_snooze = event.add_actions(2)
 	action_stop.label = 'Stop'
